MemoryRegistry

Struct MemoryRegistry 

pub struct MemoryRegistry { /* private fields */ }
An in-memory synchronous registry seeded with a fixed set of pacts.

Implementations

Source

impl MemoryRegistry

pub fn new(lease_millis: u64) -> Self

Create an empty registry that leases claims for lease_millis.

pub fn seeded(pacts: Vec<Pact>, lease_millis: u64) -> Self

Create a registry holding pacts, each available to claim, leasing claims for lease_millis.